//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[KokushiThirteenWaiting](-kokushi-thirteen-waiting.md)

# KokushiThirteenWaiting

[common]\
val [KokushiThirteenWaiting](-kokushi-thirteen-waiting.md): [Yaku](../-yaku/index.md)

国士无双十三面
